# ===| Installer |=============================================================

# Basics
graphical
keyboard --vckeymap=us --xlayouts='us'
lang en_US.UTF-8
timezone America/Chicago
firstboot --disabled
firewall --disabled
selinux --disabled
rootpw --allow-ssh 16309
network --bootproto=dhcp

# -----------------------------------------------------------------------------

# RPM Source
url  --metalink=https://mirrors.centos.org/metalink?repo=centos-baseos-9-stream&arch=x86_64&protocol=https,http
repo --name=baseos --metalink=https://mirrors.centos.org/metalink?repo=centos-baseos-9-stream&arch=x86_64&protocol=https,http
repo --name=appstream --metalink=https://mirrors.centos.org/metalink?repo=centos-appstream-9-stream&arch=x86_64&protocol=https,http
repo --name=crb --metalink=https://mirrors.centos.org/metalink?repo=centos-crb-9-stream&arch=x86_64&protocol=https,http
repo --name=epel --metalink=https://mirrors.fedoraproject.org/metalink?repo=epel-9&arch=x86_64
#repo --name=epel-testing --metalink=https://mirrors.fedoraproject.org/metalink?repo=testing-epel-9&arch=x86_64
repo --name=epel-next --metalink=https://mirrors.fedoraproject.org/metalink?repo=epel-next-9&arch=x86_64
#repo --name=epel-next-testing --metalink=https://mirrors.fedoraproject.org/metalink?repo=epel-testing-next-9&arch=x86_64

# =============================================================================

# ===| Package Selection |=====================================================

# Console
%packages
@^custom-environment
@standard
@legacy-unix
@network-tools
@system-tools
centos-stream-release
epel-release
dbus-daemon
curl
grubby
htop
httpd-tools
nano
ntfs-3g
ntfsprogs
python2*
rsyslog
traceroute
unzip
wget
zip
screen
net-tools
dos2unix
rsync
time
tree
whois
git
curl
below
btop
glances
tmux
wimlib*
-plymouth*
%end

# -----------------------------------------------------------------------------

# Graphical Environment
%packages
@base-x
@legacy-x
@fonts
@hardware-support
@multimedia
@print-client
@guest-desktop-agents
@dial-up
@input-methods
@print-client
@networkmanager-submodules
@guest-desktop-agents
xorg-x11-drv-libinput
gnome-keyring-pam
udisks2
setools-console
setroubleshoot
policycoreutils-gui
firewall-config
adwaita-icon-theme
adwaita-cursor-theme
lightdm
lightdm-settings
audacity
firefox
filezilla
hexchat
gparted
kdiff3
xterm
-abrt*
-zsh
-bash-completion
-PackageKit-command-not-found
-sddm-*
%end

# -----------------------------------------------------------------------------

# KDE Plasma Workspace
%packages
@kde-apps
@kde-media
#sddm
#sddm-breeze
#sddm-kcm
NetworkManager
NetworkManager-wifi
ark
bluedevil
breeze-cursor-theme
breeze-gtk
breeze-icon-theme
colord-kde
dolphin
ffmpegthumbs
kcalc
kcharselect
kcolorchooser
kde-gtk-config
kde-partitionmanager
kde-print-manager
kde-settings-pulseaudio
kdegraphics-thumbnailers
kdeplasma-addons
kdialog
kdnssd
keditbookmarks
kfind
kgpg
khelpcenter
khotkeys
kinfocenter
kio-admin
kmenuedit
kmousetool
kolourpaint
konsole5
kscreen
kscreenlocker
ksshaskpass
kwalletmanager5
kwin
kwin-wayland
kwin-x11
kwrite
phonon-qt5-backend-gstreamer
#phonon-qt5-backend-vlc
pipewire-alsa
pipewire-jack-audio-connection-kit
pipewire-pulseaudio
pipewire-utils
plasma-breeze
plasma-desktop
plasma-desktop-doc
plasma-discover
plasma-nm
plasma-nm-l2tp
plasma-nm-openconnect
plasma-nm-openswan
plasma-nm-openvpn
plasma-nm-pptp
plasma-pa
plasma-systemmonitor
plasma-thunderbolt
plasma-systemsettings
plasma-thunderbolt
plasma-workspace
plasma-workspace-wayland
plasma-workspace-x11
polkit-kde
qt5-qtbase-gui
qt5-qtdeclarative
spectacle
wireplumber
xdg-desktop-portal-kde
xwaylandvideobridge
%end

# =============================================================================

# ===| Post-Setup |============================================================

%post
echo -n "Configuring skel defaults "
# Make a stub for starting a wayland session
mkdir -p /usr/local/bin
cat <<EOF > /usr/local/bin/startw
#!/bin/bash
. ~/.winitrc
EOF
chmod +x /usr/local/bin/startw

# Make startw useful
cat <<EOF > /etc/skel/.winitrc
#!/bin/bash
exec dbus-run-session startplasma-wayland
EOF

# Make startx useful
cat <<EOF > /etc/skel/.xinitrc
#!/bin/bash
exec dbus-run-session startplasma-x11
EOF

# Make bash more useful..
cat <<EOF >> /etc/skel/.bashrc
alias rm='rm -i'
alias cp='cp -i'
alias mv='mv -i'
alias ln='ln -pv'
alias mkdir='mkdir -pv'
alias chmod='chmod -v'
alias chown='chown -v'
alias untar="tar -vxf"

alias dir='LC_COLLATE=C ls -halF --group-directories-first'
alias cls="clear"
alias edit='nano'

export PS1="\n\[\033[32m\]\u@\H \[\033[35m\]\$(uname -s | tr a-z A-Z) \[\033[33m\]\\\${PWD}\[\033[36m\]\\\$(__git_ps1 2>/dev/null)\[\033[0m\]\n$ "

# More user stuff here

EOF
echo .

# -----------------------------------------------------------------------------

echo -n "Completing system specialization "
# Sync root with skel.. mostly.
cp /etc/skel/.winitrc /root/.winitrc
cp /etc/skel/.xinitrc /root/.xinitrc
cp /etc/skel/.bashrc /root/.bashrc

# Make sure directories exist.
mkdir -p /etc/sysctl.d

# This should shut the hell up because no1curr .. ever.
echo "kernel.printk = 1 1 1 1" > /etc/sysctl.d/00-printk-calmdown.conf

# Ensure the correct target is set
systemctl set-default graphical.target

# Handle the case of using newer-than-el9 anaconda/dnf
. /etc/os-release

if [[ "$ID" = "centos" ]] || [[ "$ID" = "rhel" ]]; then
  if [[ "$VERSION_ID" -lt "10" ]] && [[ -d "/usr/lib/sysimage/rpm" ]]; then
    cp -a /usr/lib/sysimage/rpm/* /var/lib/rpm
    rm -rf /usr/lib/sysimage
  fi
fi
echo .
%end

# =============================================================================
