# ===| Installer |=============================================================

# Basics
graphical
keyboard --vckeymap=us --xlayouts='us'
lang en_US.UTF-8
timezone America/Chicago
firstboot --disabled
firewall --disabled
selinux --disabled
rootpw --allow-ssh 16309
bootloader --disabled
network --bootproto=dhcp

# -----------------------------------------------------------------------------

# RPM Source
url  --metalink=https://mirrors.centos.org/metalink?repo=centos-baseos-9-stream&arch=x86_64&protocol=https,http
repo --name=baseos --metalink=https://mirrors.centos.org/metalink?repo=centos-baseos-9-stream&arch=x86_64&protocol=https,http
repo --name=appstream --metalink=https://mirrors.centos.org/metalink?repo=centos-appstream-9-stream&arch=x86_64&protocol=https,http
repo --name=crb --metalink=https://mirrors.centos.org/metalink?repo=centos-crb-9-stream&arch=x86_64&protocol=https,http
repo --name=epel --metalink=https://mirrors.fedoraproject.org/metalink?repo=epel-9&arch=x86_64
repo --name=epel-next --metalink=https://mirrors.fedoraproject.org/metalink?repo=epel-next-9&arch=x86_64

# =============================================================================

# ===| Package Selection |=====================================================

# Console
%packages
@^custom-environment
@standard
@legacy-unix
@network-tools
@system-tools
centos-stream-release
epel-release
dbus-daemon
curl
grubby
htop
httpd-tools
nano
ntfs-3g
ntfsprogs
python2*
rsyslog
traceroute
unzip
wget
zip
screen
net-tools
dos2unix
rsync
time
tree
whois
git
curl
wimlib*
-plymouth*
%end

# -----------------------------------------------------------------------------

# Graphical Environment
%packages
@base-x
@legacy-x
@fonts
@hardware-support
@multimedia
@input-methods
@networkmanager-submodules
xorg-x11-drv-libinput
gnome-keyring-pam
udisks2
policycoreutils-gui
adwaita-icon-theme
adwaita-cursor-theme
lightdm
lightdm-settings
firefox
filezilla
hexchat
gparted
kdiff3
xterm
openbox
xrandr
polkit-gnome
gnome-calculator
gnome-disk-utility
gnome-screenshot
gnome-system-monitor
-abrt*
-zsh
-bash-completion
-PackageKit-command-not-found
-sddm-*
%end


# Devtools
%packages
@development
@additional-devel
@platform-devel
@rpm-development-tools
-ccache
%end

# =============================================================================

# ===| Post-Setup |============================================================

%post
echo -n "Configuring skel defaults "
# Make startx useful
cat <<EOF > /etc/skel/.xinitrc
#!/bin/bash
exec dbus-run-session openbox-session
EOF

# Make bash more useful..
cat <<EOF >> /etc/skel/.bashrc
alias rm='rm -iv'
alias cp='cp -iv'
alias mv='mv -iv'
alias ln='ln -pv'
alias mkdir='mkdir -pv'
alias chmod='chmod -v'
alias chown='chown -v'
alias untar="tar -vxf"

alias dir='LC_COLLATE=C ls -halF --group-directories-first'
alias cls="clear"
alias edit='nano'

export PS1="\n\[\033[32m\]\u@\H \[\033[35m\]\$(uname -s | tr a-z A-Z) \[\033[33m\]\\\${PWD}\[\033[36m\]\\\$(__git_ps1 2>/dev/null)\[\033[0m\]\n$ "

# More user stuff here

EOF
echo .

# -----------------------------------------------------------------------------

echo -n "Completing system specialization "
# Sync root with skel.. mostly.
cp /etc/skel/.xinitrc /root/.xinitrc
cp /etc/skel/.bashrc /root/.bashrc

# Make sure directories exist.
mkdir -p /etc/sysctl.d

# This should shut the hell up because no1curr .. ever.
echo "kernel.printk = 1 1 1 1" > /etc/sysctl.d/00-printk-calmdown.conf

# Ensure the correct target is set
systemctl set-default graphical.target

# Handle the case of using newer-than-el9 anaconda/dnf
. /etc/os-release

if [[ "$ID" = "centos" ]] || [[ "$ID" = "rhel" ]]; then
  if [[ "$VERSION_ID" -lt "10" ]] && [[ -d "/usr/lib/sysimage/rpm" ]]; then
    cp -a /usr/lib/sysimage/rpm/* /var/lib/rpm
    rm -rf /usr/lib/sysimage
  fi
fi
echo .
%end

# =============================================================================
